summaryrefslogtreecommitdiffhomepage
path: root/src/rlgl.h
diff options
context:
space:
mode:
authorraysan5 <[email protected]>2016-09-05 20:15:21 +0200
committerraysan5 <[email protected]>2016-09-05 20:15:21 +0200
commit36f20376e67c8f281467df74b82759c9a05d7018 (patch)
tree49c9fd6cc064a19915c11b9b9b284b5b568dbe52 /src/rlgl.h
parent9d66bc4a05f17f5dfe0e81b9be38f044b0dc16d4 (diff)
downloadraylib-36f20376e67c8f281467df74b82759c9a05d7018.tar.gz
raylib-36f20376e67c8f281467df74b82759c9a05d7018.zip
Redesigned lighting shader system
Diffstat (limited to 'src/rlgl.h')
-rw-r--r--src/rlgl.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/rlgl.h b/src/rlgl.h
index 3fc54219..5fc9f8b9 100644
--- a/src/rlgl.h
+++ b/src/rlgl.h
@@ -168,7 +168,9 @@ typedef enum { OPENGL_11 = 1, OPENGL_21, OPENGL_33, OPENGL_ES_20 } GlVersion;
// Uniform locations
int mvpLoc; // ModelView-Projection matrix uniform location point (vertex shader)
- int tintColorLoc; // Color uniform location point (fragment shader)
+ int colDiffuseLoc; // Color uniform location point (fragment shader)
+ int colAmbientLoc; // Ambient color uniform location point (fragment shader)
+ int colSpecularLoc; // Specular color uniform location point (fragment shader)
// Texture map locations (generic for any kind of map)
int mapTexture0Loc; // Map texture uniform location point (default-texture-unit = 0)